@@ -12,6 +12,7 @@ class TwitterOEmbedder(object):
         def tweet_processor():
             @cache.memoize(timeout=60*60*24*356)
             def oembed_tweet(tweet_id,
+                             omit_script=False,
                              access_token=app.config['TWITTER_ACCESS_TOKEN'],
                              token_secret=app.config['TWITTER_TOKEN_SECRET']):
                 auth = OAuth1(app.config['TWITTER_CONSUMER_KEY'],
@@ -19,7 +20,9 @@ class TwitterOEmbedder(object):
                               access_token,
                               token_secret)
                 url = 'https://api.twitter.com/1.1/statuses/oembed.json'
-                r = requests.get(url, params={'id':tweet_id}, auth=auth)
+                params = {'id':tweet_id,
+                          'omit_script':omit_script}
+                r = requests.get(url, params=params, auth=auth)
                 try:
                     tweet_html = Markup(r.json()[u'html'])
                 except KeyError as e:
